Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java

Issue 2714623002: [TTS] Default-enable AMP clicks promote to new tab (Closed)
Patch Set: Addressed Theresa's comment. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchManager.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java
diff --git a/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java b/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java
index a9866bac60cdad04956f3fac39401ad164349538..20d43e10c8d75464a7775eeedb35b782eca3326f 100644
--- a/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java
+++ b/chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchFieldTrial.java
@@ -81,7 +81,7 @@ public class ContextualSearchFieldTrial {
@VisibleForTesting
static final String ONLINE_DETECTION_DISABLED = "disable_online_detection";
- private static final String ENABLE_AMP_AS_SEPARATE_TAB = "enable_amp_as_separate_tab";
+ private static final String DISABLE_AMP_AS_SEPARATE_TAB = "disable_amp_as_separate_tab";
// Privacy-related flags
private static final String ENABLE_SEND_HOME_COUNTRY = "enable_send_home_country";
@@ -109,7 +109,7 @@ public class ContextualSearchFieldTrial {
private static Boolean sShouldHideContextualCardsData;
private static Boolean sIsContextualCardsBarIntegrationEnabled;
private static Boolean sIsOnlineDetectionDisabled;
- private static Boolean sIsAmpAsSeparateTabEnabled;
+ private static Boolean sIsAmpAsSeparateTabDisabled;
private static Boolean sContextualSearchSingleActionsEnabled;
private static Boolean sCanSendHomeCountry;
private static Boolean sContextualSearchUrlActionsEnabled;
@@ -367,13 +367,13 @@ public class ContextualSearchFieldTrial {
}
/**
* @return Whether to auto-promote clicks in the AMP carousel into a separate Tab.
*/
- static boolean isAmpAsSeparateTabEnabled() {
- if (sIsAmpAsSeparateTabEnabled == null) {
- sIsAmpAsSeparateTabEnabled = getBooleanParam(ENABLE_AMP_AS_SEPARATE_TAB);
+ static boolean isAmpAsSeparateTabDisabled() {
+ if (sIsAmpAsSeparateTabDisabled == null) {
+ sIsAmpAsSeparateTabDisabled = getBooleanParam(DISABLE_AMP_AS_SEPARATE_TAB);
}
- return sIsAmpAsSeparateTabEnabled;
+ return sIsAmpAsSeparateTabDisabled;
}
// TODO(donnd): Remove once bar-integration is fully landed if still unused (native only).
« no previous file with comments | « no previous file | chrome/android/java/src/org/chromium/chrome/browser/contextualsearch/ContextualSearchManager.java » ('j') | no next file with comments »
@@ -367,13 +367,13 @@ public class ContextualSearchFieldTrial {
}
/**
- * @return Whether to auto-promote clicks in the AMP carousel into a separate Tab.
+ * @return Whether to disable auto-promotion of clicks in the AMP carousel into a separate Tab.
*/

Powered by Google App Engine
This is Rietveld 408576698